==> tytalk-builder-0.0.3.tgz: package/lib/connector/index.js <==
'use strict'


/**
 * Module dependencies.
 * @private
 */

const Message = require('../message')
const Dialog = require('../conversation/dialog')
const uuidv1 = require('uuid/v1')
const Session = require('../session')

class Connector {
    constructor() {
        this.sessionStorage = {}
    }
    /**
     * monitor the client message, and pass the message to your bot.
     * the message will be processed by your bot, according the dialog flow.
     * After that, an answer or a response will send back to the client
     * 
     */
    listen() {
        const args = arguments
        return function (args) {
            //在这个方法里，为本次请求建立一个连接数据，在bot中进行处理时都是基于这个数据进行的
            const _this = this
            const [req, res] = arguments
            // dispatch the response to the client
            this.dispatch = function (answer, extension) {
                res.send({
                    status: 'ok',
                    data: _this.answerTypeCompiler(answer),
                    extension: extension
                })
            }
            let sessionId = this.getConnectorId(req)
            let session = this.sessionStorage[sessionId]
            if (!session) {
                this.sessionStorage[sessionId] = new Session()
            }
            this.session = this.sessionStorage[sessionId]
            this.session.id = sessionId
            this.session.send = this.dispatch
            this.session.end = function () {
                res.end()
            }
            this.processClientAction(req);
            return this;
        }.bind(this)
    }

    /**
     * add eventHandler to process client actions
     *  
     * TODO more types of client action
     * @param {*} req 
     */
    processClientAction(req) {
        let message = req.body.message
        this.session.message = message
        const messageAction = {
            type: 'message',
            content: new Message(message.type || 'text', message, this.id)
        }
        if (this.onEventHandler) {
            this.onEventHandler(messageAction, this.session);
        }
        return this;
    }

    onEvent(handler) {
        this.onEventHandler = handler;
    }

    /**
     * get unique id of the connector.
     * If not specified, the default connectorId will be stored in req.session.
     * And you can overwrite this method in your own connector to change this behavior
     * 
     */
    getConnectorId(req) {
        let cid
        if (req.body && req.body.cid) {
            cid = req.body.cid
        } else if (req.session) {
            cid = req.session.cid = req.session.cid || uuidv1()
        } else {
            cid = uuidv1()
        }
        return cid ? cid : uuidv1()
    }

    answerTypeCompiler(answer) {
        return answer
    }


}

module.exports = Connector

==> tytalk-builder-0.0.4.tgz: package/lib/connector/index.js <==
'use strict'


/**
 * Module dependencies.
 * @private
 */

const Message = require('../message')
const Dialog = require('../conversation/dialog')
const uuidv1 = require('uuid/v1')
const Session = require('../session')

class Connector {
    constructor() {
        this.sessionStorage = {}
    }
    /**
     * monitor the client message, and pass the message to your bot.
     * the message will be processed by your bot, according the dialog flow.
     * After that, an answer or a response will send back to the client
     * 
     */
    listen() {
        const args = arguments
        return function (args) {
            //在这个方法里，为本次请求建立一个连接数据，在bot中进行处理时都是基于这个数据进行的
            const _this = this
            const [req, res] = arguments
            // dispatch the response to the client
            this.dispatch = function (answer, extension) {
                let result = _this.answerTypeCompiler(answer)
                res.send({
                    status: 'ok',
                    data: result,
                    cid: _this.session.id,
                    extension: extension
                })
            }
            let sessionId = this.getConnectorId(req)
            let session = this.sessionStorage[sessionId]
            if (!session) {
                this.sessionStorage[sessionId] = new Session()
            }
            this.session = this.sessionStorage[sessionId]
            this.session.id = sessionId
            this.session.send = this.dispatch
            this.session.end = function () {
                res.end()
            }
            this.processClientAction(req);
            return this;
        }.bind(this)
    }

    /**
     * add eventHandler to process client actions
     *  
     * TODO more types of client action
     * @param {*} req 
     */
    processClientAction(req) {
        let message = req.body.message
        this.session.message = message
        const messageAction = {
            type: 'message',
            content: new Message(message.type || 'text', message, this.id)
        }
        if (this.onEventHandler) {
            this.onEventHandler(messageAction, this.session);
        }
        return this;
    }

    onEvent(handler) {
        this.onEventHandler = handler;
    }

    /**
     * get unique id of the connector.
     * If not specified, the default connectorId will be stored in req.session.
     * And you can overwrite this method in your own connector to change this behavior
     * 
     */
    getConnectorId(req) {
        let cid
        if (req.body && req.body.conversationId) {
            cid = req.body.conversationId
        } else if (req.session) {
            cid = req.session.conversationId = req.session.conversationId || uuidv1()
        } else {
            cid = uuidv1()
        }
        return cid ? cid : uuidv1()
    }

    answerTypeCompiler(answer) {
        return answer
    }


}

module.exports = Connector
